### Name: median
### Title: Median Partitions and Hierarchies
### Aliases: cl_median
### Keywords: cluster

### ** Examples

## Median partition for the Rosenberg-Kim kinship terms partition
## data based on co-membership dissimilarities.
data("Kinship82")
m1 <- cl_median(Kinship82, method = "GV3",
                control = list(k = 3, verbose = TRUE))
## (Note that one should really use several replicates of this.)
## Total co-membership dissimilarity:
sum(cl_dissimilarity(Kinship82, m1, "comem"))
## Compare to the consensus solution given in Gordon & Vichi (2001).
data("Kinship82_Consensus")
m2 <- Kinship82_Consensus[["JMF"]]
sum(cl_dissimilarity(Kinship82, m2, "comem"))
## Seems we get a better solution ...
## How dissimilar are these solutions?
cl_dissimilarity(m1, m2, "comem")
## How "fuzzy" are they?
cl_fuzziness(cl_ensemble(m1, m2))
## Do the "nearest" hard partitions fully agree?
cl_dissimilarity(as.cl_hard_partition(m1),
                 as.cl_hard_partition(m2))
## Hmm ...

## Median partition for the Gordon and Vichi (2001) macroeconomic
## partition data based on Euclidean dissimilarities.
data("Macro")
set.seed(1)
m1 <- cl_median(Macro, method = "GV1",
                control = list(k = 2, verbose = TRUE))
## (Note that one should really use several replicates of this.)
## Total Euclidean dissimilarity:
sum(cl_dissimilarity(Macro, m1))
## Compare to the consensus solution given in Gordon & Vichi (2001).
data("Macro_Consensus")
m2 <- Macro_Consensus[["MF1"]]
sum(cl_dissimilarity(Macro, m2))
## Seems we get a better solution ...
## And in fact, it is qualitatively different:
table(as.cl_hard_partition(m1),
      as.cl_hard_partition(m2))
## Hmm ...



